@@ -8,8 +8,10 @@ import msgpack as _msgpack
 
 
 def packb(data: Any, **kwargs) -> bytes:
-    return _msgpack.packb(data, use_bin_type=True, **kwargs)
+    opts = {"use_bin_type": True, **kwargs}
+    return _msgpack.packb(data, **opts)
 
 
 def unpackb(packed: bytes, **kwargs) -> Any:
-    return _msgpack.unpackb(packed, raw=False, use_list=False, **kwargs)
+    opts = {"raw": False, "use_list": False, **kwargs}
+    return _msgpack.unpackb(packed, **opts)
