@@ -14,7 +14,6 @@ from typing import (
     Optional,
     Sequence,
     Tuple,
-    Union,
 )
 
 import aioredis
@@ -119,7 +118,7 @@ async def subscribe(
                 await _reset_chan()
                 continue
             raise
-        except asyncio.TimeoutError:
+        except (TimeoutError, asyncio.TimeoutError):
             continue
         except asyncio.CancelledError:
             raise
@@ -178,7 +177,7 @@ async def blpop(
                 await asyncio.sleep(reconnect_poll_interval)
                 continue
             raise
-        except asyncio.TimeoutError:
+        except (TimeoutError, asyncio.TimeoutError):
             continue
         except asyncio.CancelledError:
             raise
@@ -258,11 +257,11 @@ async def execute(
             await asyncio.sleep(reconnect_poll_interval)
             continue
         except aioredis.exceptions.ResponseError as e:
-            if "NOREPLICAS" in e.args[0]:
+            if e.args[0].startswith("NOREPLICAS "):
                 await asyncio.sleep(reconnect_poll_interval)
                 continue
             raise
-        except asyncio.TimeoutError:
+        except (TimeoutError, asyncio.TimeoutError):
             continue
         except asyncio.CancelledError:
             raise
@@ -275,7 +274,7 @@ async def execute_script(
     script_id: str,
     script: str,
     keys: Sequence[str],
-    args: Sequence[Union[bytes, memoryview, str, int, float]],  # aioredis.connection.EncodableT
+    args: Sequence[str],
 ) -> Any:
     """
     Auto-load and execute the given script.
@@ -323,7 +322,7 @@ async def read_stream(
     """
     A high-level wrapper for the XREAD command.
     """
-    last_id = b'$'
+    last_id = b'0-0'
     while True:
         try:
             reply = await execute(
@@ -335,14 +334,11 @@ async def read_stream(
             )
             if reply is None:
                 continue
-            # Keep some latest messages so that other manager
-            # processes to have chances of fetching them.
             await execute(
                 r,
-                lambda r: r.xtrim(
+                lambda r: r.xdel(
                     stream_key,
-                    maxlen=128,
-                    approximate=True,
+                    *(msg_id for msg_id, msg_data in reply[0][1]),
                 ),
             )
             for msg_id, msg_data in reply[0][1]:
