@@ -1,7 +1,6 @@
 '''
 An extension module to Trafaret which provides additional type checkers.
 '''
-from __future__ import annotations
 
 import datetime
 from decimal import Decimal
@@ -30,6 +29,7 @@ import uuid
 import pwd
 
 import dateutil.tz
+from dateutil.relativedelta import relativedelta
 try:
     import jwt
     jwt_available = True
@@ -309,7 +309,6 @@ class HostPortPair(t.Trafaret):
         self._allow_blank_host = allow_blank_host
 
     def check_and_return(self, value: Any) -> Tuple[ipaddress._BaseAddress, int]:
-        host: str | ipaddress._BaseAddress
         if isinstance(value, str):
             pair = value.rsplit(':', maxsplit=1)
             if len(pair) == 1:
@@ -463,11 +462,33 @@ class TimeZone(t.Trafaret):
 
 
 class TimeDuration(t.Trafaret):
+    '''
+    Represent the relative difference between two datetime objects,
+    parsed from human-readable time duration expression strings.
 
+    If you specify years or months, it returns an
+    :class:`dateutil.relativedelta.relativedelta` instance
+    which keeps the human-friendly year and month calculation
+    considering leap years and monthly day count differences,
+    instead of simply multiplying 365 days to the value of years.
+    Otherwise, it returns the stdlib's :class:`datetime.timedelta`
+    instance.
+
+    Example:
+    >>> t = datetime(2020, 2, 29)
+    >>> t + check_and_return(years=1)
+    datetime.datetime(2021, 2, 28, 0, 0)
+    >>> t + check_and_return(years=2)
+    datetime.datetime(2022, 2, 28, 0, 0)
+    >>> t + check_and_return(years=3)
+    datetime.datetime(2023, 2, 28, 0, 0)
+    >>> t + check_and_return(years=4)
+    datetime.datetime(2024, 2, 29, 0, 0)  # preserves the same day of month
+    '''
     def __init__(self, *, allow_negative: bool = False) -> None:
         self._allow_negative = allow_negative
 
-    def check_and_return(self, value: Any) -> datetime.timedelta:
+    def check_and_return(self, value: Any) -> Union[datetime.timedelta, relativedelta]:
         if not isinstance(value, str):
             self._failure('value must be string', value=value)
         if len(value) == 0:
@@ -479,6 +500,16 @@ class TimeDuration(t.Trafaret):
                 if not self._allow_negative and t < 0:
                     self._failure('value must be positive', value=value)
                 return datetime.timedelta(seconds=t)
+            elif value[-2:].isalpha():
+                t = int(value[:-2])
+                if not self._allow_negative and t < 0:
+                    self._failure('value must be positive', value=value)
+                if value[-2:] == 'yr':
+                    return relativedelta(years=t)
+                elif value[-2:] == 'mo':
+                    return relativedelta(months=t)
+                else:
+                    self._failure('value is not a known time duration', value=value)
             else:
                 t = float(value[:-1])
                 if not self._allow_negative and t < 0:
